OC.L10N.register(
    "spreed",
    {
    "None" : "ஒன்றுமில்லை",
    "User" : "User",
    "Users" : "பயனாளர்",
    "Name" : "பெயர்",
    "Favorite" : "விருப்பமான",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "குழுக்கள்",
    "Error" : "வழு",
    "Password protect" : "கடவுச்சொல்லை பாதுகாத்தல்",
    "Back" : "பின்னுக்கு",
    "Close" : "மூடுக",
    "Today" : "இன்று",
    "Add users or groups" : "Add users or groups",
    "Settings" : "அமைப்புகள்",
    "Edit" : "தொகுக்க",
    "Share link" : "Share link",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Password" : "கடவுச்சொல்",
    "Cancel" : "இரத்து செய்க",
    "Change password" : "கடவுச்சொல்லை மாற்றுக",
    "Rename" : "பெயர்மாற்றம்",
    "Share" : "பகிர்வு",
    "Error while sharing" : "பகிரும் போதான வழு",
    "Contacts" : "தொடர்புகள்"
},
"nplurals=2; plural=(n != 1);");
